# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .deploy_stage import DeployStage
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FunctionDeployStage(DeployStage):
    """
    Specifies the Function stage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FunctionDeployStage object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.FunctionDeployStage.deploy_stage_type` attribute
        of this class is ``DEPLOY_FUNCTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this FunctionDeployStage.
        :type id: str

        :param description:
            The value to assign to the description property of this FunctionDeployStage.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this FunctionDeployStage.
        :type display_name: str

        :param project_id:
            The value to assign to the project_id property of this FunctionDeployStage.
        :type project_id: str

        :param deploy_pipeline_id:
            The value to assign to the deploy_pipeline_id property of this FunctionDeployStage.
        :type deploy_pipeline_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this FunctionDeployStage.
        :type compartment_id: str

        :param deploy_stage_type:
            The value to assign to the deploy_stage_type property of this FunctionDeployStage.
            Allowed values for this property are: "WAIT", "COMPUTE_INSTANCE_GROUP_ROLLING_DEPLOYMENT", "OKE_DEPLOYMENT", "DEPLOY_FUNCTION", "INVOKE_FUNCTION", "LOAD_BALANCER_TRAFFIC_SHIFT", "MANUAL_APPROVAL"
        :type deploy_stage_type: str

        :param time_created:
            The value to assign to the time_created property of this FunctionDeployStage.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this FunctionDeployStage.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this FunctionDeployStage.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this FunctionDeployStage.
        :type lifecycle_details: str

        :param deploy_stage_predecessor_collection:
            The value to assign to the deploy_stage_predecessor_collection property of this FunctionDeployStage.
        :type deploy_stage_predecessor_collection: oci.devops.models.DeployStagePredecessorCollection

        :param freeform_tags:
            The value to assign to the freeform_tags property of this FunctionDeployStage.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this FunctionDeployStage.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this FunctionDeployStage.
        :type system_tags: dict(str, dict(str, object))

        :param function_deploy_environment_id:
            The value to assign to the function_deploy_environment_id property of this FunctionDeployStage.
        :type function_deploy_environment_id: str

        :param docker_image_deploy_artifact_id:
            The value to assign to the docker_image_deploy_artifact_id property of this FunctionDeployStage.
        :type docker_image_deploy_artifact_id: str

        :param config:
            The value to assign to the config property of this FunctionDeployStage.
        :type config: dict(str, str)

        :param max_memory_in_mbs:
            The value to assign to the max_memory_in_mbs property of this FunctionDeployStage.
        :type max_memory_in_mbs: int

        :param function_timeout_in_seconds:
            The value to assign to the function_timeout_in_seconds property of this FunctionDeployStage.
        :type function_timeout_in_seconds: int

        """
        self.swagger_types = {
            'id': 'str',
            'description': 'str',
            'display_name': 'str',
            'project_id': 'str',
            'deploy_pipeline_id': 'str',
            'compartment_id': 'str',
            'deploy_stage_type': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'deploy_stage_predecessor_collection': 'DeployStagePredecessorCollection',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'function_deploy_environment_id': 'str',
            'docker_image_deploy_artifact_id': 'str',
            'config': 'dict(str, str)',
            'max_memory_in_mbs': 'int',
            'function_timeout_in_seconds': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'description': 'description',
            'display_name': 'displayName',
            'project_id': 'projectId',
            'deploy_pipeline_id': 'deployPipelineId',
            'compartment_id': 'compartmentId',
            'deploy_stage_type': 'deployStageType',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'deploy_stage_predecessor_collection': 'deployStagePredecessorCollection',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'function_deploy_environment_id': 'functionDeployEnvironmentId',
            'docker_image_deploy_artifact_id': 'dockerImageDeployArtifactId',
            'config': 'config',
            'max_memory_in_mbs': 'maxMemoryInMBs',
            'function_timeout_in_seconds': 'functionTimeoutInSeconds'
        }

        self._id = None
        self._description = None
        self._display_name = None
        self._project_id = None
        self._deploy_pipeline_id = None
        self._compartment_id = None
        self._deploy_stage_type = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._deploy_stage_predecessor_collection = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._function_deploy_environment_id = None
        self._docker_image_deploy_artifact_id = None
        self._config = None
        self._max_memory_in_mbs = None
        self._function_timeout_in_seconds = None
        self._deploy_stage_type = 'DEPLOY_FUNCTION'

    @property
    def function_deploy_environment_id(self):
        """
        **[Required]** Gets the function_deploy_environment_id of this FunctionDeployStage.
        Function environment OCID.


        :return: The function_deploy_environment_id of this FunctionDeployStage.
        :rtype: str
        """
        return self._function_deploy_environment_id

    @function_deploy_environment_id.setter
    def function_deploy_environment_id(self, function_deploy_environment_id):
        """
        Sets the function_deploy_environment_id of this FunctionDeployStage.
        Function environment OCID.


        :param function_deploy_environment_id: The function_deploy_environment_id of this FunctionDeployStage.
        :type: str
        """
        self._function_deploy_environment_id = function_deploy_environment_id

    @property
    def docker_image_deploy_artifact_id(self):
        """
        **[Required]** Gets the docker_image_deploy_artifact_id of this FunctionDeployStage.
        A Docker image artifact OCID.


        :return: The docker_image_deploy_artifact_id of this FunctionDeployStage.
        :rtype: str
        """
        return self._docker_image_deploy_artifact_id

    @docker_image_deploy_artifact_id.setter
    def docker_image_deploy_artifact_id(self, docker_image_deploy_artifact_id):
        """
        Sets the docker_image_deploy_artifact_id of this FunctionDeployStage.
        A Docker image artifact OCID.


        :param docker_image_deploy_artifact_id: The docker_image_deploy_artifact_id of this FunctionDeployStage.
        :type: str
        """
        self._docker_image_deploy_artifact_id = docker_image_deploy_artifact_id

    @property
    def config(self):
        """
        Gets the config of this FunctionDeployStage.
        User provided key and value pair configuration, which is assigned through constants or parameter.


        :return: The config of this FunctionDeployStage.
        :rtype: dict(str, str)
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this FunctionDeployStage.
        User provided key and value pair configuration, which is assigned through constants or parameter.


        :param config: The config of this FunctionDeployStage.
        :type: dict(str, str)
        """
        self._config = config

    @property
    def max_memory_in_mbs(self):
        """
        Gets the max_memory_in_mbs of this FunctionDeployStage.
        Maximum usable memory for the Function (in MB).


        :return: The max_memory_in_mbs of this FunctionDeployStage.
        :rtype: int
        """
        return self._max_memory_in_mbs

    @max_memory_in_mbs.setter
    def max_memory_in_mbs(self, max_memory_in_mbs):
        """
        Sets the max_memory_in_mbs of this FunctionDeployStage.
        Maximum usable memory for the Function (in MB).


        :param max_memory_in_mbs: The max_memory_in_mbs of this FunctionDeployStage.
        :type: int
        """
        self._max_memory_in_mbs = max_memory_in_mbs

    @property
    def function_timeout_in_seconds(self):
        """
        Gets the function_timeout_in_seconds of this FunctionDeployStage.
        Timeout for execution of the Function. Value in seconds.


        :return: The function_timeout_in_seconds of this FunctionDeployStage.
        :rtype: int
        """
        return self._function_timeout_in_seconds

    @function_timeout_in_seconds.setter
    def function_timeout_in_seconds(self, function_timeout_in_seconds):
        """
        Sets the function_timeout_in_seconds of this FunctionDeployStage.
        Timeout for execution of the Function. Value in seconds.


        :param function_timeout_in_seconds: The function_timeout_in_seconds of this FunctionDeployStage.
        :type: int
        """
        self._function_timeout_in_seconds = function_timeout_in_seconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateMigrationDetails(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Create Migration resource parameters.
    """

    #: A constant which can be used with the type property of a CreateMigrationDetails.
    #: This constant has a value of "ONLINE"
    TYPE_ONLINE = "ONLINE"

    #: A constant which can be used with the type property of a CreateMigrationDetails.
    #: This constant has a value of "OFFLINE"
    TYPE_OFFLINE = "OFFLINE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateMigrationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this CreateMigrationDetails.
            Allowed values for this property are: "ONLINE", "OFFLINE"
        :type type: str

        :param display_name:
            The value to assign to the display_name property of this CreateMigrationDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateMigrationDetails.
        :type compartment_id: str

        :param agent_id:
            The value to assign to the agent_id property of this CreateMigrationDetails.
        :type agent_id: str

        :param source_database_connection_id:
            The value to assign to the source_database_connection_id property of this CreateMigrationDetails.
        :type source_database_connection_id: str

        :param source_container_database_connection_id:
            The value to assign to the source_container_database_connection_id property of this CreateMigrationDetails.
        :type source_container_database_connection_id: str

        :param target_database_connection_id:
            The value to assign to the target_database_connection_id property of this CreateMigrationDetails.
        :type target_database_connection_id: str

        :param data_transfer_medium_details:
            The value to assign to the data_transfer_medium_details property of this CreateMigrationDetails.
        :type data_transfer_medium_details: oci.database_migration.models.CreateDataTransferMediumDetails

        :param datapump_settings:
            The value to assign to the datapump_settings property of this CreateMigrationDetails.
        :type datapump_settings: oci.database_migration.models.CreateDataPumpSettings

        :param exclude_objects:
            The value to assign to the exclude_objects property of this CreateMigrationDetails.
        :type exclude_objects: list[oci.database_migration.models.DatabaseObject]

        :param golden_gate_details:
            The value to assign to the golden_gate_details property of this CreateMigrationDetails.
        :type golden_gate_details: oci.database_migration.models.CreateGoldenGateDetails

        :param vault_details:
            The value to assign to the vault_details property of this CreateMigrationDetails.
        :type vault_details: oci.database_migration.models.CreateVaultDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateMigrationDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateMigrationDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'type': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'agent_id': 'str',
            'source_database_connection_id': 'str',
            'source_container_database_connection_id': 'str',
            'target_database_connection_id': 'str',
            'data_transfer_medium_details': 'CreateDataTransferMediumDetails',
            'datapump_settings': 'CreateDataPumpSettings',
            'exclude_objects': 'list[DatabaseObject]',
            'golden_gate_details': 'CreateGoldenGateDetails',
            'vault_details': 'CreateVaultDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'type': 'type',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'agent_id': 'agentId',
            'source_database_connection_id': 'sourceDatabaseConnectionId',
            'source_container_database_connection_id': 'sourceContainerDatabaseConnectionId',
            'target_database_connection_id': 'targetDatabaseConnectionId',
            'data_transfer_medium_details': 'dataTransferMediumDetails',
            'datapump_settings': 'datapumpSettings',
            'exclude_objects': 'excludeObjects',
            'golden_gate_details': 'goldenGateDetails',
            'vault_details': 'vaultDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._type = None
        self._display_name = None
        self._compartment_id = None
        self._agent_id = None
        self._source_database_connection_id = None
        self._source_container_database_connection_id = None
        self._target_database_connection_id = None
        self._data_transfer_medium_details = None
        self._datapump_settings = None
        self._exclude_objects = None
        self._golden_gate_details = None
        self._vault_details = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def type(self):
        """
        **[Required]** Gets the type of this CreateMigrationDetails.
        Migration type.

        Allowed values for this property are: "ONLINE", "OFFLINE"


        :return: The type of this CreateMigrationDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CreateMigrationDetails.
        Migration type.


        :param type: The type of this CreateMigrationDetails.
        :type: str
        """
        allowed_values = ["ONLINE", "OFFLINE"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            raise ValueError(
                "Invalid value for `type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateMigrationDetails.
        Migration Display Name


        :return: The display_name of this CreateMigrationDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateMigrationDetails.
        Migration Display Name


        :param display_name: The display_name of this CreateMigrationDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateMigrationDetails.
        OCID of the compartment


        :return: The compartment_id of this CreateMigrationDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateMigrationDetails.
        OCID of the compartment


        :param compartment_id: The compartment_id of this CreateMigrationDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def agent_id(self):
        """
        Gets the agent_id of this CreateMigrationDetails.
        The OCID of the registered ODMS Agent. Only valid for Offline Logical Migrations.


        :return: The agent_id of this CreateMigrationDetails.
        :rtype: str
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """
        Sets the agent_id of this CreateMigrationDetails.
        The OCID of the registered ODMS Agent. Only valid for Offline Logical Migrations.


        :param agent_id: The agent_id of this CreateMigrationDetails.
        :type: str
        """
        self._agent_id = agent_id

    @property
    def source_database_connection_id(self):
        """
        **[Required]** Gets the source_database_connection_id of this CreateMigrationDetails.
        The OCID of the Source Database Connection.


        :return: The source_database_connection_id of this CreateMigrationDetails.
        :rtype: str
        """
        return self._source_database_connection_id

    @source_database_connection_id.setter
    def source_database_connection_id(self, source_database_connection_id):
        """
        Sets the source_database_connection_id of this CreateMigrationDetails.
        The OCID of the Source Database Connection.


        :param source_database_connection_id: The source_database_connection_id of this CreateMigrationDetails.
        :type: str
        """
        self._source_database_connection_id = source_database_connection_id

    @property
    def source_container_database_connection_id(self):
        """
        Gets the source_container_database_connection_id of this CreateMigrationDetails.
        The OCID of the Source Container Database Connection. Only used for Online migrations.
        Only Connections of type Non-Autonomous can be used as source container databases.


        :return: The source_container_database_connection_id of this CreateMigrationDetails.
        :rtype: str
        """
        return self._source_container_database_connection_id

    @source_container_database_connection_id.setter
    def source_container_database_connection_id(self, source_container_database_connection_id):
        """
        Sets the source_container_database_connection_id of this CreateMigrationDetails.
        The OCID of the Source Container Database Connection. Only used for Online migrations.
        Only Connections of type Non-Autonomous can be used as source container databases.


        :param source_container_database_connection_id: The source_container_database_connection_id of this CreateMigrationDetails.
        :type: str
        """
        self._source_container_database_connection_id = source_container_database_connection_id

    @property
    def target_database_connection_id(self):
        """
        **[Required]** Gets the target_database_connection_id of this CreateMigrationDetails.
        The OCID of the Target Database Connection.


        :return: The target_database_connection_id of this CreateMigrationDetails.
        :rtype: str
        """
        return self._target_database_connection_id

    @target_database_connection_id.setter
    def target_database_connection_id(self, target_database_connection_id):
        """
        Sets the target_database_connection_id of this CreateMigrationDetails.
        The OCID of the Target Database Connection.


        :param target_database_connection_id: The target_database_connection_id of this CreateMigrationDetails.
        :type: str
        """
        self._target_database_connection_id = target_database_connection_id

    @property
    def data_transfer_medium_details(self):
        """
        Gets the data_transfer_medium_details of this CreateMigrationDetails.

        :return: The data_transfer_medium_details of this CreateMigrationDetails.
        :rtype: oci.database_migration.models.CreateDataTransferMediumDetails
        """
        return self._data_transfer_medium_details

    @data_transfer_medium_details.setter
    def data_transfer_medium_details(self, data_transfer_medium_details):
        """
        Sets the data_transfer_medium_details of this CreateMigrationDetails.

        :param data_transfer_medium_details: The data_transfer_medium_details of this CreateMigrationDetails.
        :type: oci.database_migration.models.CreateDataTransferMediumDetails
        """
        self._data_transfer_medium_details = data_transfer_medium_details

    @property
    def datapump_settings(self):
        """
        Gets the datapump_settings of this CreateMigrationDetails.

        :return: The datapump_settings of this CreateMigrationDetails.
        :rtype: oci.database_migration.models.CreateDataPumpSettings
        """
        return self._datapump_settings

    @datapump_settings.setter
    def datapump_settings(self, datapump_settings):
        """
        Sets the datapump_settings of this CreateMigrationDetails.

        :param datapump_settings: The datapump_settings of this CreateMigrationDetails.
        :type: oci.database_migration.models.CreateDataPumpSettings
        """
        self._datapump_settings = datapump_settings

    @property
    def exclude_objects(self):
        """
        Gets the exclude_objects of this CreateMigrationDetails.
        Database objects to exclude from migration.


        :return: The exclude_objects of this CreateMigrationDetails.
        :rtype: list[oci.database_migration.models.DatabaseObject]
        """
        return self._exclude_objects

    @exclude_objects.setter
    def exclude_objects(self, exclude_objects):
        """
        Sets the exclude_objects of this CreateMigrationDetails.
        Database objects to exclude from migration.


        :param exclude_objects: The exclude_objects of this CreateMigrationDetails.
        :type: list[oci.database_migration.models.DatabaseObject]
        """
        self._exclude_objects = exclude_objects

    @property
    def golden_gate_details(self):
        """
        Gets the golden_gate_details of this CreateMigrationDetails.

        :return: The golden_gate_details of this CreateMigrationDetails.
        :rtype: oci.database_migration.models.CreateGoldenGateDetails
        """
        return self._golden_gate_details

    @golden_gate_details.setter
    def golden_gate_details(self, golden_gate_details):
        """
        Sets the golden_gate_details of this CreateMigrationDetails.

        :param golden_gate_details: The golden_gate_details of this CreateMigrationDetails.
        :type: oci.database_migration.models.CreateGoldenGateDetails
        """
        self._golden_gate_details = golden_gate_details

    @property
    def vault_details(self):
        """
        Gets the vault_details of this CreateMigrationDetails.

        :return: The vault_details of this CreateMigrationDetails.
        :rtype: oci.database_migration.models.CreateVaultDetails
        """
        return self._vault_details

    @vault_details.setter
    def vault_details(self, vault_details):
        """
        Sets the vault_details of this CreateMigrationDetails.

        :param vault_details: The vault_details of this CreateMigrationDetails.
        :type: oci.database_migration.models.CreateVaultDetails
        """
        self._vault_details = vault_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateMigrationDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateMigrationDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateMigrationDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateMigrationDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateMigrationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateMigrationDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateMigrationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateMigrationDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateBlockchainPlatformDetails(object):
    """
    Blockchain Platform details for creating a new service.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateBlockchainPlatformDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateBlockchainPlatformDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateBlockchainPlatformDetails.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this CreateBlockchainPlatformDetails.
        :type description: str

        :param platform_role:
            The value to assign to the platform_role property of this CreateBlockchainPlatformDetails.
        :type platform_role: str

        :param compute_shape:
            The value to assign to the compute_shape property of this CreateBlockchainPlatformDetails.
        :type compute_shape: str

        :param is_byol:
            The value to assign to the is_byol property of this CreateBlockchainPlatformDetails.
        :type is_byol: bool

        :param idcs_access_token:
            The value to assign to the idcs_access_token property of this CreateBlockchainPlatformDetails.
        :type idcs_access_token: str

        :param federated_user_id:
            The value to assign to the federated_user_id property of this CreateBlockchainPlatformDetails.
        :type federated_user_id: str

        :param ca_cert_archive_text:
            The value to assign to the ca_cert_archive_text property of this CreateBlockchainPlatformDetails.
        :type ca_cert_archive_text: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateBlockchainPlatformDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateBlockchainPlatformDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'description': 'str',
            'platform_role': 'str',
            'compute_shape': 'str',
            'is_byol': 'bool',
            'idcs_access_token': 'str',
            'federated_user_id': 'str',
            'ca_cert_archive_text': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'description': 'description',
            'platform_role': 'platformRole',
            'compute_shape': 'computeShape',
            'is_byol': 'isByol',
            'idcs_access_token': 'idcsAccessToken',
            'federated_user_id': 'federatedUserId',
            'ca_cert_archive_text': 'caCertArchiveText',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._description = None
        self._platform_role = None
        self._compute_shape = None
        self._is_byol = None
        self._idcs_access_token = None
        self._federated_user_id = None
        self._ca_cert_archive_text = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateBlockchainPlatformDetails.
        Platform Instance Display name, can be renamed


        :return: The display_name of this CreateBlockchainPlatformDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateBlockchainPlatformDetails.
        Platform Instance Display name, can be renamed


        :param display_name: The display_name of this CreateBlockchainPlatformDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateBlockchainPlatformDetails.
        Compartment Identifier


        :return: The compartment_id of this CreateBlockchainPlatformDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateBlockchainPlatformDetails.
        Compartment Identifier


        :param compartment_id: The compartment_id of this CreateBlockchainPlatformDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this CreateBlockchainPlatformDetails.
        Platform Instance Description


        :return: The description of this CreateBlockchainPlatformDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateBlockchainPlatformDetails.
        Platform Instance Description


        :param description: The description of this CreateBlockchainPlatformDetails.
        :type: str
        """
        self._description = description

    @property
    def platform_role(self):
        """
        **[Required]** Gets the platform_role of this CreateBlockchainPlatformDetails.
        Role of platform - founder or participant


        :return: The platform_role of this CreateBlockchainPlatformDetails.
        :rtype: str
        """
        return self._platform_role

    @platform_role.setter
    def platform_role(self, platform_role):
        """
        Sets the platform_role of this CreateBlockchainPlatformDetails.
        Role of platform - founder or participant


        :param platform_role: The platform_role of this CreateBlockchainPlatformDetails.
        :type: str
        """
        self._platform_role = platform_role

    @property
    def compute_shape(self):
        """
        **[Required]** Gets the compute_shape of this CreateBlockchainPlatformDetails.
        Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE


        :return: The compute_shape of this CreateBlockchainPlatformDetails.
        :rtype: str
        """
        return self._compute_shape

    @compute_shape.setter
    def compute_shape(self, compute_shape):
        """
        Sets the compute_shape of this CreateBlockchainPlatformDetails.
        Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE


        :param compute_shape: The compute_shape of this CreateBlockchainPlatformDetails.
        :type: str
        """
        self._compute_shape = compute_shape

    @property
    def is_byol(self):
        """
        Gets the is_byol of this CreateBlockchainPlatformDetails.
        Bring your own license


        :return: The is_byol of this CreateBlockchainPlatformDetails.
        :rtype: bool
        """
        return self._is_byol

    @is_byol.setter
    def is_byol(self, is_byol):
        """
        Sets the is_byol of this CreateBlockchainPlatformDetails.
        Bring your own license


        :param is_byol: The is_byol of this CreateBlockchainPlatformDetails.
        :type: bool
        """
        self._is_byol = is_byol

    @property
    def idcs_access_token(self):
        """
        **[Required]** Gets the idcs_access_token of this CreateBlockchainPlatformDetails.
        IDCS access token with Identity Domain Administrator role


        :return: The idcs_access_token of this CreateBlockchainPlatformDetails.
        :rtype: str
        """
        return self._idcs_access_token

    @idcs_access_token.setter
    def idcs_access_token(self, idcs_access_token):
        """
        Sets the idcs_access_token of this CreateBlockchainPlatformDetails.
        IDCS access token with Identity Domain Administrator role


        :param idcs_access_token: The idcs_access_token of this CreateBlockchainPlatformDetails.
        :type: str
        """
        self._idcs_access_token = idcs_access_token

    @property
    def federated_user_id(self):
        """
        Gets the federated_user_id of this CreateBlockchainPlatformDetails.
        Identifier for a federated user


        :return: The federated_user_id of this CreateBlockchainPlatformDetails.
        :rtype: str
        """
        return self._federated_user_id

    @federated_user_id.setter
    def federated_user_id(self, federated_user_id):
        """
        Sets the federated_user_id of this CreateBlockchainPlatformDetails.
        Identifier for a federated user


        :param federated_user_id: The federated_user_id of this CreateBlockchainPlatformDetails.
        :type: str
        """
        self._federated_user_id = federated_user_id

    @property
    def ca_cert_archive_text(self):
        """
        Gets the ca_cert_archive_text of this CreateBlockchainPlatformDetails.
        Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file.
        The Archive file is a zip file containing third part CA Certificates,
        the ca key and certificate files used when issuing enrollment certificates
        (ECerts) and transaction certificates (TCerts). The chainfile (if it exists)
        contains the certificate chain which should be trusted for this CA, where
        the 1st in the chain is always the root CA certificate.
        File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].


        :return: The ca_cert_archive_text of this CreateBlockchainPlatformDetails.
        :rtype: str
        """
        return self._ca_cert_archive_text

    @ca_cert_archive_text.setter
    def ca_cert_archive_text(self, ca_cert_archive_text):
        """
        Sets the ca_cert_archive_text of this CreateBlockchainPlatformDetails.
        Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file.
        The Archive file is a zip file containing third part CA Certificates,
        the ca key and certificate files used when issuing enrollment certificates
        (ECerts) and transaction certificates (TCerts). The chainfile (if it exists)
        contains the certificate chain which should be trusted for this CA, where
        the 1st in the chain is always the root CA certificate.
        File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].


        :param ca_cert_archive_text: The ca_cert_archive_text of this CreateBlockchainPlatformDetails.
        :type: str
        """
        self._ca_cert_archive_text = ca_cert_archive_text

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateBlockchainPlatformDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateBlockchainPlatformDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateBlockchainPlatformDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateBlockchainPlatformDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateBlockchainPlatformDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateBlockchainPlatformDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateBlockchainPlatformDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateBlockchainPlatformDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MigrateVaultKeyDetails(object):
    """
    Details for replacing existing Oracle-managed keys with customer-managed `Vault service`__ keys and vice-versa is not supported.

    __ https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MigrateVaultKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kms_key_id:
            The value to assign to the kms_key_id property of this MigrateVaultKeyDetails.
        :type kms_key_id: str

        :param kms_key_version_id:
            The value to assign to the kms_key_version_id property of this MigrateVaultKeyDetails.
        :type kms_key_version_id: str

        """
        self.swagger_types = {
            'kms_key_id': 'str',
            'kms_key_version_id': 'str'
        }

        self.attribute_map = {
            'kms_key_id': 'kmsKeyId',
            'kms_key_version_id': 'kmsKeyVersionId'
        }

        self._kms_key_id = None
        self._kms_key_version_id = None

    @property
    def kms_key_id(self):
        """
        **[Required]** Gets the kms_key_id of this MigrateVaultKeyDetails.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :return: The kms_key_id of this MigrateVaultKeyDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this MigrateVaultKeyDetails.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :param kms_key_id: The kms_key_id of this MigrateVaultKeyDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def kms_key_version_id(self):
        """
        Gets the kms_key_version_id of this MigrateVaultKeyDetails.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :return: The kms_key_version_id of this MigrateVaultKeyDetails.
        :rtype: str
        """
        return self._kms_key_version_id

    @kms_key_version_id.setter
    def kms_key_version_id(self, kms_key_version_id):
        """
        Sets the kms_key_version_id of this MigrateVaultKeyDetails.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :param kms_key_version_id: The kms_key_version_id of this MigrateVaultKeyDetails.
        :type: str
        """
        self._kms_key_version_id = kms_key_version_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PublicationSummary(object):
    """
    The model for a summary of an Oracle Cloud Infrastructure publication.
    """

    #: A constant which can be used with the package_type property of a PublicationSummary.
    #: This constant has a value of "ORCHESTRATION"
    PACKAGE_TYPE_ORCHESTRATION = "ORCHESTRATION"

    #: A constant which can be used with the package_type property of a PublicationSummary.
    #: This constant has a value of "IMAGE"
    PACKAGE_TYPE_IMAGE = "IMAGE"

    #: A constant which can be used with the listing_type property of a PublicationSummary.
    #: This constant has a value of "COMMUNITY"
    LISTING_TYPE_COMMUNITY = "COMMUNITY"

    #: A constant which can be used with the listing_type property of a PublicationSummary.
    #: This constant has a value of "PARTNER"
    LISTING_TYPE_PARTNER = "PARTNER"

    #: A constant which can be used with the listing_type property of a PublicationSummary.
    #: This constant has a value of "PRIVATE"
    LISTING_TYPE_PRIVATE = "PRIVATE"

    def __init__(self, **kwargs):
        """
        Initializes a new PublicationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this PublicationSummary.
        :type lifecycle_state: str

        :param compartment_id:
            The value to assign to the compartment_id property of this PublicationSummary.
        :type compartment_id: str

        :param id:
            The value to assign to the id property of this PublicationSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this PublicationSummary.
        :type name: str

        :param short_description:
            The value to assign to the short_description property of this PublicationSummary.
        :type short_description: str

        :param icon:
            The value to assign to the icon property of this PublicationSummary.
        :type icon: oci.marketplace.models.UploadData

        :param package_type:
            The value to assign to the package_type property of this PublicationSummary.
            Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type package_type: str

        :param supported_operating_systems:
            The value to assign to the supported_operating_systems property of this PublicationSummary.
        :type supported_operating_systems: list[oci.marketplace.models.OperatingSystem]

        :param listing_type:
            The value to assign to the listing_type property of this PublicationSummary.
            Allowed values for this property are: "COMMUNITY", "PARTNER", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type listing_type: str

        :param time_created:
            The value to assign to the time_created property of this PublicationSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'lifecycle_state': 'str',
            'compartment_id': 'str',
            'id': 'str',
            'name': 'str',
            'short_description': 'str',
            'icon': 'UploadData',
            'package_type': 'str',
            'supported_operating_systems': 'list[OperatingSystem]',
            'listing_type': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'lifecycle_state': 'lifecycleState',
            'compartment_id': 'compartmentId',
            'id': 'id',
            'name': 'name',
            'short_description': 'shortDescription',
            'icon': 'icon',
            'package_type': 'packageType',
            'supported_operating_systems': 'supportedOperatingSystems',
            'listing_type': 'listingType',
            'time_created': 'timeCreated'
        }

        self._lifecycle_state = None
        self._compartment_id = None
        self._id = None
        self._name = None
        self._short_description = None
        self._icon = None
        self._package_type = None
        self._supported_operating_systems = None
        self._listing_type = None
        self._time_created = None

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this PublicationSummary.
        The lifecycle state of the publication.


        :return: The lifecycle_state of this PublicationSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this PublicationSummary.
        The lifecycle state of the publication.


        :param lifecycle_state: The lifecycle_state of this PublicationSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this PublicationSummary.
        The `OCID`__ of the compartment where the publication exists.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this PublicationSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this PublicationSummary.
        The `OCID`__ of the compartment where the publication exists.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this PublicationSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this PublicationSummary.
        The unique identifier for the publication in Marketplace.


        :return: The id of this PublicationSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PublicationSummary.
        The unique identifier for the publication in Marketplace.


        :param id: The id of this PublicationSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this PublicationSummary.
        The name of the publication, which is also used in the listing.


        :return: The name of this PublicationSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PublicationSummary.
        The name of the publication, which is also used in the listing.


        :param name: The name of this PublicationSummary.
        :type: str
        """
        self._name = name

    @property
    def short_description(self):
        """
        Gets the short_description of this PublicationSummary.
        A short description of the publication to use in the listing.


        :return: The short_description of this PublicationSummary.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this PublicationSummary.
        A short description of the publication to use in the listing.


        :param short_description: The short_description of this PublicationSummary.
        :type: str
        """
        self._short_description = short_description

    @property
    def icon(self):
        """
        Gets the icon of this PublicationSummary.

        :return: The icon of this PublicationSummary.
        :rtype: oci.marketplace.models.UploadData
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon of this PublicationSummary.

        :param icon: The icon of this PublicationSummary.
        :type: oci.marketplace.models.UploadData
        """
        self._icon = icon

    @property
    def package_type(self):
        """
        Gets the package_type of this PublicationSummary.
        The listing's package type.

        Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The package_type of this PublicationSummary.
        :rtype: str
        """
        return self._package_type

    @package_type.setter
    def package_type(self, package_type):
        """
        Sets the package_type of this PublicationSummary.
        The listing's package type.


        :param package_type: The package_type of this PublicationSummary.
        :type: str
        """
        allowed_values = ["ORCHESTRATION", "IMAGE"]
        if not value_allowed_none_or_none_sentinel(package_type, allowed_values):
            package_type = 'UNKNOWN_ENUM_VALUE'
        self._package_type = package_type

    @property
    def supported_operating_systems(self):
        """
        Gets the supported_operating_systems of this PublicationSummary.
        The list of operating systems supported by the listing.


        :return: The supported_operating_systems of this PublicationSummary.
        :rtype: list[oci.marketplace.models.OperatingSystem]
        """
        return self._supported_operating_systems

    @supported_operating_systems.setter
    def supported_operating_systems(self, supported_operating_systems):
        """
        Sets the supported_operating_systems of this PublicationSummary.
        The list of operating systems supported by the listing.


        :param supported_operating_systems: The supported_operating_systems of this PublicationSummary.
        :type: list[oci.marketplace.models.OperatingSystem]
        """
        self._supported_operating_systems = supported_operating_systems

    @property
    def listing_type(self):
        """
        **[Required]** Gets the listing_type of this PublicationSummary.
        The publisher category to which the publication belongs. The publisher category informs where the listing appears for use.

        Allowed values for this property are: "COMMUNITY", "PARTNER", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The listing_type of this PublicationSummary.
        :rtype: str
        """
        return self._listing_type

    @listing_type.setter
    def listing_type(self, listing_type):
        """
        Sets the listing_type of this PublicationSummary.
        The publisher category to which the publication belongs. The publisher category informs where the listing appears for use.


        :param listing_type: The listing_type of this PublicationSummary.
        :type: str
        """
        allowed_values = ["COMMUNITY", "PARTNER", "PRIVATE"]
        if not value_allowed_none_or_none_sentinel(listing_type, allowed_values):
            listing_type = 'UNKNOWN_ENUM_VALUE'
        self._listing_type = listing_type

    @property
    def time_created(self):
        """
        Gets the time_created of this PublicationSummary.
        The date and time the publication was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this PublicationSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this PublicationSummary.
        The date and time the publication was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this PublicationSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsSourceEntityType(object):
    """
    LogAnalyticsSourceEntityType
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsSourceEntityType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_id:
            The value to assign to the source_id property of this LogAnalyticsSourceEntityType.
        :type source_id: int

        :param entity_type:
            The value to assign to the entity_type property of this LogAnalyticsSourceEntityType.
        :type entity_type: str

        :param entity_type_category:
            The value to assign to the entity_type_category property of this LogAnalyticsSourceEntityType.
        :type entity_type_category: str

        :param entity_type_display_name:
            The value to assign to the entity_type_display_name property of this LogAnalyticsSourceEntityType.
        :type entity_type_display_name: str

        """
        self.swagger_types = {
            'source_id': 'int',
            'entity_type': 'str',
            'entity_type_category': 'str',
            'entity_type_display_name': 'str'
        }

        self.attribute_map = {
            'source_id': 'sourceId',
            'entity_type': 'entityType',
            'entity_type_category': 'entityTypeCategory',
            'entity_type_display_name': 'entityTypeDisplayName'
        }

        self._source_id = None
        self._entity_type = None
        self._entity_type_category = None
        self._entity_type_display_name = None

    @property
    def source_id(self):
        """
        Gets the source_id of this LogAnalyticsSourceEntityType.
        The source unique identifier.


        :return: The source_id of this LogAnalyticsSourceEntityType.
        :rtype: int
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LogAnalyticsSourceEntityType.
        The source unique identifier.


        :param source_id: The source_id of this LogAnalyticsSourceEntityType.
        :type: int
        """
        self._source_id = source_id

    @property
    def entity_type(self):
        """
        Gets the entity_type of this LogAnalyticsSourceEntityType.
        The entity type.


        :return: The entity_type of this LogAnalyticsSourceEntityType.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this LogAnalyticsSourceEntityType.
        The entity type.


        :param entity_type: The entity_type of this LogAnalyticsSourceEntityType.
        :type: str
        """
        self._entity_type = entity_type

    @property
    def entity_type_category(self):
        """
        Gets the entity_type_category of this LogAnalyticsSourceEntityType.
        The type category.


        :return: The entity_type_category of this LogAnalyticsSourceEntityType.
        :rtype: str
        """
        return self._entity_type_category

    @entity_type_category.setter
    def entity_type_category(self, entity_type_category):
        """
        Sets the entity_type_category of this LogAnalyticsSourceEntityType.
        The type category.


        :param entity_type_category: The entity_type_category of this LogAnalyticsSourceEntityType.
        :type: str
        """
        self._entity_type_category = entity_type_category

    @property
    def entity_type_display_name(self):
        """
        Gets the entity_type_display_name of this LogAnalyticsSourceEntityType.
        The entity type display name.


        :return: The entity_type_display_name of this LogAnalyticsSourceEntityType.
        :rtype: str
        """
        return self._entity_type_display_name

    @entity_type_display_name.setter
    def entity_type_display_name(self, entity_type_display_name):
        """
        Sets the entity_type_display_name of this LogAnalyticsSourceEntityType.
        The entity type display name.


        :param entity_type_display_name: The entity_type_display_name of this LogAnalyticsSourceEntityType.
        :type: str
        """
        self._entity_type_display_name = entity_type_display_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreatePluggableDatabaseDetails(object):
    """
    Parameters for creating a pluggable database in a specified container database (CDB).

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreatePluggableDatabaseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param pdb_name:
            The value to assign to the pdb_name property of this CreatePluggableDatabaseDetails.
        :type pdb_name: str

        :param container_database_id:
            The value to assign to the container_database_id property of this CreatePluggableDatabaseDetails.
        :type container_database_id: str

        :param pdb_admin_password:
            The value to assign to the pdb_admin_password property of this CreatePluggableDatabaseDetails.
        :type pdb_admin_password: str

        :param tde_wallet_password:
            The value to assign to the tde_wallet_password property of this CreatePluggableDatabaseDetails.
        :type tde_wallet_password: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreatePluggableDatabaseDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreatePluggableDatabaseDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'pdb_name': 'str',
            'container_database_id': 'str',
            'pdb_admin_password': 'str',
            'tde_wallet_password': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'pdb_name': 'pdbName',
            'container_database_id': 'containerDatabaseId',
            'pdb_admin_password': 'pdbAdminPassword',
            'tde_wallet_password': 'tdeWalletPassword',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._pdb_name = None
        self._container_database_id = None
        self._pdb_admin_password = None
        self._tde_wallet_password = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def pdb_name(self):
        """
        **[Required]** Gets the pdb_name of this CreatePluggableDatabaseDetails.
        The name for the pluggable database (PDB). The name is unique in the context of a :class:`Database`. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.


        :return: The pdb_name of this CreatePluggableDatabaseDetails.
        :rtype: str
        """
        return self._pdb_name

    @pdb_name.setter
    def pdb_name(self, pdb_name):
        """
        Sets the pdb_name of this CreatePluggableDatabaseDetails.
        The name for the pluggable database (PDB). The name is unique in the context of a :class:`Database`. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.


        :param pdb_name: The pdb_name of this CreatePluggableDatabaseDetails.
        :type: str
        """
        self._pdb_name = pdb_name

    @property
    def container_database_id(self):
        """
        **[Required]** Gets the container_database_id of this CreatePluggableDatabaseDetails.
        The `OCID`__ of the CDB

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The container_database_id of this CreatePluggableDatabaseDetails.
        :rtype: str
        """
        return self._container_database_id

    @container_database_id.setter
    def container_database_id(self, container_database_id):
        """
        Sets the container_database_id of this CreatePluggableDatabaseDetails.
        The `OCID`__ of the CDB

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param container_database_id: The container_database_id of this CreatePluggableDatabaseDetails.
        :type: str
        """
        self._container_database_id = container_database_id

    @property
    def pdb_admin_password(self):
        """
        **[Required]** Gets the pdb_admin_password of this CreatePluggableDatabaseDetails.
        A strong password for PDB Admin. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :return: The pdb_admin_password of this CreatePluggableDatabaseDetails.
        :rtype: str
        """
        return self._pdb_admin_password

    @pdb_admin_password.setter
    def pdb_admin_password(self, pdb_admin_password):
        """
        Sets the pdb_admin_password of this CreatePluggableDatabaseDetails.
        A strong password for PDB Admin. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :param pdb_admin_password: The pdb_admin_password of this CreatePluggableDatabaseDetails.
        :type: str
        """
        self._pdb_admin_password = pdb_admin_password

    @property
    def tde_wallet_password(self):
        """
        **[Required]** Gets the tde_wallet_password of this CreatePluggableDatabaseDetails.
        The existing TDE wallet password of the CDB.


        :return: The tde_wallet_password of this CreatePluggableDatabaseDetails.
        :rtype: str
        """
        return self._tde_wallet_password

    @tde_wallet_password.setter
    def tde_wallet_password(self, tde_wallet_password):
        """
        Sets the tde_wallet_password of this CreatePluggableDatabaseDetails.
        The existing TDE wallet password of the CDB.


        :param tde_wallet_password: The tde_wallet_password of this CreatePluggableDatabaseDetails.
        :type: str
        """
        self._tde_wallet_password = tde_wallet_password

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreatePluggableDatabaseDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreatePluggableDatabaseDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreatePluggableDatabaseDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreatePluggableDatabaseDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreatePluggableDatabaseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreatePluggableDatabaseDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreatePluggableDatabaseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreatePluggableDatabaseDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import


from .appliance_export_job_client import ApplianceExportJobClient
from .appliance_export_job_client_composite_operations import ApplianceExportJobClientCompositeOperations
from .shipping_vendors_client import ShippingVendorsClient
from .shipping_vendors_client_composite_operations import ShippingVendorsClientCompositeOperations
from .transfer_appliance_client import TransferApplianceClient
from .transfer_appliance_client_composite_operations import TransferApplianceClientCompositeOperations
from .transfer_appliance_entitlement_client import TransferApplianceEntitlementClient
from .transfer_appliance_entitlement_client_composite_operations import TransferApplianceEntitlementClientCompositeOperations
from .transfer_device_client import TransferDeviceClient
from .transfer_device_client_composite_operations import TransferDeviceClientCompositeOperations
from .transfer_job_client import TransferJobClient
from .transfer_job_client_composite_operations import TransferJobClientCompositeOperations
from .transfer_package_client import TransferPackageClient
from .transfer_package_client_composite_operations import TransferPackageClientCompositeOperations
from . import models

__all__ = ["ApplianceExportJobClient", "ApplianceExportJobClientCompositeOperations", "ShippingVendorsClient", "ShippingVendorsClientCompositeOperations", "TransferApplianceClient", "TransferApplianceClientCompositeOperations", "TransferApplianceEntitlementClient", "TransferApplianceEntitlementClientCompositeOperations", "TransferDeviceClient", "TransferDeviceClientCompositeOperations", "TransferJobClient", "TransferJobClientCompositeOperations", "TransferPackageClient", "TransferPackageClientCompositeOperations", "models"]



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlText(object):
    """
    SQL Text type object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlText object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param version:
            The value to assign to the version property of this SqlText.
        :type version: float

        :param sql_identifier:
            The value to assign to the sql_identifier property of this SqlText.
        :type sql_identifier: str

        :param time_collected:
            The value to assign to the time_collected property of this SqlText.
        :type time_collected: datetime

        :param sql_command:
            The value to assign to the sql_command property of this SqlText.
        :type sql_command: str

        :param exact_matching_signature:
            The value to assign to the exact_matching_signature property of this SqlText.
        :type exact_matching_signature: str

        :param force_matching_signature:
            The value to assign to the force_matching_signature property of this SqlText.
        :type force_matching_signature: str

        :param sql_full_text:
            The value to assign to the sql_full_text property of this SqlText.
        :type sql_full_text: str

        """
        self.swagger_types = {
            'version': 'float',
            'sql_identifier': 'str',
            'time_collected': 'datetime',
            'sql_command': 'str',
            'exact_matching_signature': 'str',
            'force_matching_signature': 'str',
            'sql_full_text': 'str'
        }

        self.attribute_map = {
            'version': 'version',
            'sql_identifier': 'sqlIdentifier',
            'time_collected': 'timeCollected',
            'sql_command': 'sqlCommand',
            'exact_matching_signature': 'exactMatchingSignature',
            'force_matching_signature': 'forceMatchingSignature',
            'sql_full_text': 'sqlFullText'
        }

        self._version = None
        self._sql_identifier = None
        self._time_collected = None
        self._sql_command = None
        self._exact_matching_signature = None
        self._force_matching_signature = None
        self._sql_full_text = None

    @property
    def version(self):
        """
        Gets the version of this SqlText.
        Version
        Example: `1`


        :return: The version of this SqlText.
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this SqlText.
        Version
        Example: `1`


        :param version: The version of this SqlText.
        :type: float
        """
        self._version = version

    @property
    def sql_identifier(self):
        """
        **[Required]** Gets the sql_identifier of this SqlText.
        Unique SQL_ID for a SQL Statement.


        :return: The sql_identifier of this SqlText.
        :rtype: str
        """
        return self._sql_identifier

    @sql_identifier.setter
    def sql_identifier(self, sql_identifier):
        """
        Sets the sql_identifier of this SqlText.
        Unique SQL_ID for a SQL Statement.


        :param sql_identifier: The sql_identifier of this SqlText.
        :type: str
        """
        self._sql_identifier = sql_identifier

    @property
    def time_collected(self):
        """
        **[Required]** Gets the time_collected of this SqlText.
        Collection timestamp
        Example: `\"2020-05-06T00:00:00.000Z\"`


        :return: The time_collected of this SqlText.
        :rtype: datetime
        """
        return self._time_collected

    @time_collected.setter
    def time_collected(self, time_collected):
        """
        Sets the time_collected of this SqlText.
        Collection timestamp
        Example: `\"2020-05-06T00:00:00.000Z\"`


        :param time_collected: The time_collected of this SqlText.
        :type: datetime
        """
        self._time_collected = time_collected

    @property
    def sql_command(self):
        """
        **[Required]** Gets the sql_command of this SqlText.
        SQL command
        Example: `\"SELECT\"`


        :return: The sql_command of this SqlText.
        :rtype: str
        """
        return self._sql_command

    @sql_command.setter
    def sql_command(self, sql_command):
        """
        Sets the sql_command of this SqlText.
        SQL command
        Example: `\"SELECT\"`


        :param sql_command: The sql_command of this SqlText.
        :type: str
        """
        self._sql_command = sql_command

    @property
    def exact_matching_signature(self):
        """
        Gets the exact_matching_signature of this SqlText.
        Exact matching signature
        Example: `\"18067345456756876713\"`


        :return: The exact_matching_signature of this SqlText.
        :rtype: str
        """
        return self._exact_matching_signature

    @exact_matching_signature.setter
    def exact_matching_signature(self, exact_matching_signature):
        """
        Sets the exact_matching_signature of this SqlText.
        Exact matching signature
        Example: `\"18067345456756876713\"`


        :param exact_matching_signature: The exact_matching_signature of this SqlText.
        :type: str
        """
        self._exact_matching_signature = exact_matching_signature

    @property
    def force_matching_signature(self):
        """
        Gets the force_matching_signature of this SqlText.
        Force matching signature
        Example: `\"18067345456756876713\"`


        :return: The force_matching_signature of this SqlText.
        :rtype: str
        """
        return self._force_matching_signature

    @force_matching_signature.setter
    def force_matching_signature(self, force_matching_signature):
        """
        Sets the force_matching_signature of this SqlText.
        Force matching signature
        Example: `\"18067345456756876713\"`


        :param force_matching_signature: The force_matching_signature of this SqlText.
        :type: str
        """
        self._force_matching_signature = force_matching_signature

    @property
    def sql_full_text(self):
        """
        **[Required]** Gets the sql_full_text of this SqlText.
        Full SQL Text
        Example: `\"SELECT username,profile,default_tablespace,temporary_tablespace FROM dba_users\"`
        Disclaimer: SQL text being uploaded explicitly via APIs is not masked. Any sensitive literals contained in the sqlFullText column should be masked prior to ingestion.


        :return: The sql_full_text of this SqlText.
        :rtype: str
        """
        return self._sql_full_text

    @sql_full_text.setter
    def sql_full_text(self, sql_full_text):
        """
        Sets the sql_full_text of this SqlText.
        Full SQL Text
        Example: `\"SELECT username,profile,default_tablespace,temporary_tablespace FROM dba_users\"`
        Disclaimer: SQL text being uploaded explicitly via APIs is not masked. Any sensitive literals contained in the sqlFullText column should be masked prior to ingestion.


        :param sql_full_text: The sql_full_text of this SqlText.
        :type: str
        """
        self._sql_full_text = sql_full_text

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectRelationship(object):
    """
    Details regarding a specific object and its relationship to the referencing object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectRelationship object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param relationship_type:
            The value to assign to the relationship_type property of this ObjectRelationship.
        :type relationship_type: str

        :param key:
            The value to assign to the key property of this ObjectRelationship.
        :type key: str

        :param name:
            The value to assign to the name property of this ObjectRelationship.
        :type name: str

        :param type_name:
            The value to assign to the type_name property of this ObjectRelationship.
        :type type_name: str

        :param type_key:
            The value to assign to the type_key property of this ObjectRelationship.
        :type type_key: str

        :param time_created:
            The value to assign to the time_created property of this ObjectRelationship.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ObjectRelationship.
        :type time_updated: datetime

        :param path:
            The value to assign to the path property of this ObjectRelationship.
        :type path: str

        :param parent_key:
            The value to assign to the parent_key property of this ObjectRelationship.
        :type parent_key: str

        :param parent_path:
            The value to assign to the parent_path property of this ObjectRelationship.
        :type parent_path: str

        """
        self.swagger_types = {
            'relationship_type': 'str',
            'key': 'str',
            'name': 'str',
            'type_name': 'str',
            'type_key': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'path': 'str',
            'parent_key': 'str',
            'parent_path': 'str'
        }

        self.attribute_map = {
            'relationship_type': 'relationshipType',
            'key': 'key',
            'name': 'name',
            'type_name': 'typeName',
            'type_key': 'typeKey',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'path': 'path',
            'parent_key': 'parentKey',
            'parent_path': 'parentPath'
        }

        self._relationship_type = None
        self._key = None
        self._name = None
        self._type_name = None
        self._type_key = None
        self._time_created = None
        self._time_updated = None
        self._path = None
        self._parent_key = None
        self._parent_path = None

    @property
    def relationship_type(self):
        """
        Gets the relationship_type of this ObjectRelationship.
        Type of relationship with the referencing object.


        :return: The relationship_type of this ObjectRelationship.
        :rtype: str
        """
        return self._relationship_type

    @relationship_type.setter
    def relationship_type(self, relationship_type):
        """
        Sets the relationship_type of this ObjectRelationship.
        Type of relationship with the referencing object.


        :param relationship_type: The relationship_type of this ObjectRelationship.
        :type: str
        """
        self._relationship_type = relationship_type

    @property
    def key(self):
        """
        Gets the key of this ObjectRelationship.
        Unique id of the object.


        :return: The key of this ObjectRelationship.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ObjectRelationship.
        Unique id of the object.


        :param key: The key of this ObjectRelationship.
        :type: str
        """
        self._key = key

    @property
    def name(self):
        """
        Gets the name of this ObjectRelationship.
        Name of the object.


        :return: The name of this ObjectRelationship.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ObjectRelationship.
        Name of the object.


        :param name: The name of this ObjectRelationship.
        :type: str
        """
        self._name = name

    @property
    def type_name(self):
        """
        Gets the type_name of this ObjectRelationship.
        Type name of the object. Type names can be found via the '/types' endpoint.


        :return: The type_name of this ObjectRelationship.
        :rtype: str
        """
        return self._type_name

    @type_name.setter
    def type_name(self, type_name):
        """
        Sets the type_name of this ObjectRelationship.
        Type name of the object. Type names can be found via the '/types' endpoint.


        :param type_name: The type_name of this ObjectRelationship.
        :type: str
        """
        self._type_name = type_name

    @property
    def type_key(self):
        """
        Gets the type_key of this ObjectRelationship.
        Type key of the object. Type keys can be found via the '/types' endpoint.


        :return: The type_key of this ObjectRelationship.
        :rtype: str
        """
        return self._type_key

    @type_key.setter
    def type_key(self, type_key):
        """
        Sets the type_key of this ObjectRelationship.
        Type key of the object. Type keys can be found via the '/types' endpoint.


        :param type_key: The type_key of this ObjectRelationship.
        :type: str
        """
        self._type_key = type_key

    @property
    def time_created(self):
        """
        Gets the time_created of this ObjectRelationship.
        The date and time the relationship was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ObjectRelationship.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ObjectRelationship.
        The date and time the relationship was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ObjectRelationship.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ObjectRelationship.
        The last time a change was made to this reference. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this ObjectRelationship.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ObjectRelationship.
        The last time a change was made to this reference. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this ObjectRelationship.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def path(self):
        """
        Gets the path of this ObjectRelationship.
        Full path of the object.


        :return: The path of this ObjectRelationship.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ObjectRelationship.
        Full path of the object.


        :param path: The path of this ObjectRelationship.
        :type: str
        """
        self._path = path

    @property
    def parent_key(self):
        """
        Gets the parent_key of this ObjectRelationship.
        Key of the parent object for the resource.


        :return: The parent_key of this ObjectRelationship.
        :rtype: str
        """
        return self._parent_key

    @parent_key.setter
    def parent_key(self, parent_key):
        """
        Sets the parent_key of this ObjectRelationship.
        Key of the parent object for the resource.


        :param parent_key: The parent_key of this ObjectRelationship.
        :type: str
        """
        self._parent_key = parent_key

    @property
    def parent_path(self):
        """
        Gets the parent_path of this ObjectRelationship.
        Full path of the parent object.


        :return: The parent_path of this ObjectRelationship.
        :rtype: str
        """
        return self._parent_path

    @parent_path.setter
    def parent_path(self, parent_path):
        """
        Sets the parent_path of this ObjectRelationship.
        Full path of the parent object.


        :param parent_path: The parent_path of this ObjectRelationship.
        :type: str
        """
        self._parent_path = parent_path

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .target_resource_details import TargetResourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagedSshSessionTargetResourceDetails(TargetResourceDetails):
    """
    Details about a managed SSH session for a target resource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ManagedSshSessionTargetResourceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.bastion.models.ManagedSshSessionTargetResourceDetails.session_type` attribute
        of this class is ``MANAGED_SSH`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param session_type:
            The value to assign to the session_type property of this ManagedSshSessionTargetResourceDetails.
            Allowed values for this property are: "MANAGED_SSH", "PORT_FORWARDING"
        :type session_type: str

        :param target_resource_port:
            The value to assign to the target_resource_port property of this ManagedSshSessionTargetResourceDetails.
        :type target_resource_port: int

        :param target_resource_operating_system_user_name:
            The value to assign to the target_resource_operating_system_user_name property of this ManagedSshSessionTargetResourceDetails.
        :type target_resource_operating_system_user_name: str

        :param target_resource_id:
            The value to assign to the target_resource_id property of this ManagedSshSessionTargetResourceDetails.
        :type target_resource_id: str

        :param target_resource_private_ip_address:
            The value to assign to the target_resource_private_ip_address property of this ManagedSshSessionTargetResourceDetails.
        :type target_resource_private_ip_address: str

        :param target_resource_display_name:
            The value to assign to the target_resource_display_name property of this ManagedSshSessionTargetResourceDetails.
        :type target_resource_display_name: str

        """
        self.swagger_types = {
            'session_type': 'str',
            'target_resource_port': 'int',
            'target_resource_operating_system_user_name': 'str',
            'target_resource_id': 'str',
            'target_resource_private_ip_address': 'str',
            'target_resource_display_name': 'str'
        }

        self.attribute_map = {
            'session_type': 'sessionType',
            'target_resource_port': 'targetResourcePort',
            'target_resource_operating_system_user_name': 'targetResourceOperatingSystemUserName',
            'target_resource_id': 'targetResourceId',
            'target_resource_private_ip_address': 'targetResourcePrivateIpAddress',
            'target_resource_display_name': 'targetResourceDisplayName'
        }

        self._session_type = None
        self._target_resource_port = None
        self._target_resource_operating_system_user_name = None
        self._target_resource_id = None
        self._target_resource_private_ip_address = None
        self._target_resource_display_name = None
        self._session_type = 'MANAGED_SSH'

    @property
    def target_resource_operating_system_user_name(self):
        """
        **[Required]** Gets the target_resource_operating_system_user_name of this ManagedSshSessionTargetResourceDetails.
        The name of the user on the target resource operating system that the session uses for the connection.


        :return: The target_resource_operating_system_user_name of this ManagedSshSessionTargetResourceDetails.
        :rtype: str
        """
        return self._target_resource_operating_system_user_name

    @target_resource_operating_system_user_name.setter
    def target_resource_operating_system_user_name(self, target_resource_operating_system_user_name):
        """
        Sets the target_resource_operating_system_user_name of this ManagedSshSessionTargetResourceDetails.
        The name of the user on the target resource operating system that the session uses for the connection.


        :param target_resource_operating_system_user_name: The target_resource_operating_system_user_name of this ManagedSshSessionTargetResourceDetails.
        :type: str
        """
        self._target_resource_operating_system_user_name = target_resource_operating_system_user_name

    @property
    def target_resource_id(self):
        """
        **[Required]** Gets the target_resource_id of this ManagedSshSessionTargetResourceDetails.
        The unique identifier (OCID) of the target resource (a Compute instance, for example) that the session connects to.


        :return: The target_resource_id of this ManagedSshSessionTargetResourceDetails.
        :rtype: str
        """
        return self._target_resource_id

    @target_resource_id.setter
    def target_resource_id(self, target_resource_id):
        """
        Sets the target_resource_id of this ManagedSshSessionTargetResourceDetails.
        The unique identifier (OCID) of the target resource (a Compute instance, for example) that the session connects to.


        :param target_resource_id: The target_resource_id of this ManagedSshSessionTargetResourceDetails.
        :type: str
        """
        self._target_resource_id = target_resource_id

    @property
    def target_resource_private_ip_address(self):
        """
        Gets the target_resource_private_ip_address of this ManagedSshSessionTargetResourceDetails.
        The private IP address of the target resource that the session connects to.


        :return: The target_resource_private_ip_address of this ManagedSshSessionTargetResourceDetails.
        :rtype: str
        """
        return self._target_resource_private_ip_address

    @target_resource_private_ip_address.setter
    def target_resource_private_ip_address(self, target_resource_private_ip_address):
        """
        Sets the target_resource_private_ip_address of this ManagedSshSessionTargetResourceDetails.
        The private IP address of the target resource that the session connects to.


        :param target_resource_private_ip_address: The target_resource_private_ip_address of this ManagedSshSessionTargetResourceDetails.
        :type: str
        """
        self._target_resource_private_ip_address = target_resource_private_ip_address

    @property
    def target_resource_display_name(self):
        """
        **[Required]** Gets the target_resource_display_name of this ManagedSshSessionTargetResourceDetails.
        The display name of the target Compute instance that the session connects to.


        :return: The target_resource_display_name of this ManagedSshSessionTargetResourceDetails.
        :rtype: str
        """
        return self._target_resource_display_name

    @target_resource_display_name.setter
    def target_resource_display_name(self, target_resource_display_name):
        """
        Sets the target_resource_display_name of this ManagedSshSessionTargetResourceDetails.
        The display name of the target Compute instance that the session connects to.


        :param target_resource_display_name: The target_resource_display_name of this ManagedSshSessionTargetResourceDetails.
        :type: str
        """
        self._target_resource_display_name = target_resource_display_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutoScalePolicyMetricRule(object):
    """
    Metric and threshold details for triggering an autoscale action.
    """

    #: A constant which can be used with the metric_type property of a AutoScalePolicyMetricRule.
    #: This constant has a value of "CPU_UTILIZATION"
    METRIC_TYPE_CPU_UTILIZATION = "CPU_UTILIZATION"

    def __init__(self, **kwargs):
        """
        Initializes a new AutoScalePolicyMetricRule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_type:
            The value to assign to the metric_type property of this AutoScalePolicyMetricRule.
            Allowed values for this property are: "CPU_UTILIZATION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type metric_type: str

        :param threshold:
            The value to assign to the threshold property of this AutoScalePolicyMetricRule.
        :type threshold: oci.bds.models.MetricThresholdRule

        """
        self.swagger_types = {
            'metric_type': 'str',
            'threshold': 'MetricThresholdRule'
        }

        self.attribute_map = {
            'metric_type': 'metricType',
            'threshold': 'threshold'
        }

        self._metric_type = None
        self._threshold = None

    @property
    def metric_type(self):
        """
        **[Required]** Gets the metric_type of this AutoScalePolicyMetricRule.
        Allowed value is CPU_UTILIZATION.

        Allowed values for this property are: "CPU_UTILIZATION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The metric_type of this AutoScalePolicyMetricRule.
        :rtype: str
        """
        return self._metric_type

    @metric_type.setter
    def metric_type(self, metric_type):
        """
        Sets the metric_type of this AutoScalePolicyMetricRule.
        Allowed value is CPU_UTILIZATION.


        :param metric_type: The metric_type of this AutoScalePolicyMetricRule.
        :type: str
        """
        allowed_values = ["CPU_UTILIZATION"]
        if not value_allowed_none_or_none_sentinel(metric_type, allowed_values):
            metric_type = 'UNKNOWN_ENUM_VALUE'
        self._metric_type = metric_type

    @property
    def threshold(self):
        """
        **[Required]** Gets the threshold of this AutoScalePolicyMetricRule.

        :return: The threshold of this AutoScalePolicyMetricRule.
        :rtype: oci.bds.models.MetricThresholdRule
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """
        Sets the threshold of this AutoScalePolicyMetricRule.

        :param threshold: The threshold of this AutoScalePolicyMetricRule.
        :type: oci.bds.models.MetricThresholdRule
        """
        self._threshold = threshold

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCustomEndpointDetails(object):
    """
    Details for a custom endpoint for the integration instance (update).
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCustomEndpointDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param hostname:
            The value to assign to the hostname property of this CreateCustomEndpointDetails.
        :type hostname: str

        :param certificate_secret_id:
            The value to assign to the certificate_secret_id property of this CreateCustomEndpointDetails.
        :type certificate_secret_id: str

        """
        self.swagger_types = {
            'hostname': 'str',
            'certificate_secret_id': 'str'
        }

        self.attribute_map = {
            'hostname': 'hostname',
            'certificate_secret_id': 'certificateSecretId'
        }

        self._hostname = None
        self._certificate_secret_id = None

    @property
    def hostname(self):
        """
        **[Required]** Gets the hostname of this CreateCustomEndpointDetails.
        A custom hostname to be used for the integration instance URL, in FQDN format.


        :return: The hostname of this CreateCustomEndpointDetails.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this CreateCustomEndpointDetails.
        A custom hostname to be used for the integration instance URL, in FQDN format.


        :param hostname: The hostname of this CreateCustomEndpointDetails.
        :type: str
        """
        self._hostname = hostname

    @property
    def certificate_secret_id(self):
        """
        Gets the certificate_secret_id of this CreateCustomEndpointDetails.
        Optional OCID of a vault/secret containing a private SSL certificate bundle to be used for the custom hostname.
        All certificates should be stored in a single base64 encoded secret
        Note the update will fail if this is not a valid certificate.


        :return: The certificate_secret_id of this CreateCustomEndpointDetails.
        :rtype: str
        """
        return self._certificate_secret_id

    @certificate_secret_id.setter
    def certificate_secret_id(self, certificate_secret_id):
        """
        Sets the certificate_secret_id of this CreateCustomEndpointDetails.
        Optional OCID of a vault/secret containing a private SSL certificate bundle to be used for the custom hostname.
        All certificates should be stored in a single base64 encoded secret
        Note the update will fail if this is not a valid certificate.


        :param certificate_secret_id: The certificate_secret_id of this CreateCustomEndpointDetails.
        :type: str
        """
        self._certificate_secret_id = certificate_secret_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JsChallenge(object):
    """
    The JavaScript challenge settings. JavaScript Challenge is the function to filter abnormal or malicious bots and allow access to real clients.
    """

    #: A constant which can be used with the action property of a JsChallenge.
    #: This constant has a value of "DETECT"
    ACTION_DETECT = "DETECT"

    #: A constant which can be used with the action property of a JsChallenge.
    #: This constant has a value of "BLOCK"
    ACTION_BLOCK = "BLOCK"

    def __init__(self, **kwargs):
        """
        Initializes a new JsChallenge object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_enabled:
            The value to assign to the is_enabled property of this JsChallenge.
        :type is_enabled: bool

        :param action:
            The value to assign to the action property of this JsChallenge.
            Allowed values for this property are: "DETECT", "BLOCK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action: str

        :param failure_threshold:
            The value to assign to the failure_threshold property of this JsChallenge.
        :type failure_threshold: int

        :param action_expiration_in_seconds:
            The value to assign to the action_expiration_in_seconds property of this JsChallenge.
        :type action_expiration_in_seconds: int

        :param set_http_header:
            The value to assign to the set_http_header property of this JsChallenge.
        :type set_http_header: oci.waas.models.Header

        :param challenge_settings:
            The value to assign to the challenge_settings property of this JsChallenge.
        :type challenge_settings: oci.waas.models.BlockChallengeSettings

        :param are_redirects_challenged:
            The value to assign to the are_redirects_challenged property of this JsChallenge.
        :type are_redirects_challenged: bool

        :param criteria:
            The value to assign to the criteria property of this JsChallenge.
        :type criteria: list[oci.waas.models.AccessRuleCriteria]

        :param is_nat_enabled:
            The value to assign to the is_nat_enabled property of this JsChallenge.
        :type is_nat_enabled: bool

        """
        self.swagger_types = {
            'is_enabled': 'bool',
            'action': 'str',
            'failure_threshold': 'int',
            'action_expiration_in_seconds': 'int',
            'set_http_header': 'Header',
            'challenge_settings': 'BlockChallengeSettings',
            'are_redirects_challenged': 'bool',
            'criteria': 'list[AccessRuleCriteria]',
            'is_nat_enabled': 'bool'
        }

        self.attribute_map = {
            'is_enabled': 'isEnabled',
            'action': 'action',
            'failure_threshold': 'failureThreshold',
            'action_expiration_in_seconds': 'actionExpirationInSeconds',
            'set_http_header': 'setHttpHeader',
            'challenge_settings': 'challengeSettings',
            'are_redirects_challenged': 'areRedirectsChallenged',
            'criteria': 'criteria',
            'is_nat_enabled': 'isNatEnabled'
        }

        self._is_enabled = None
        self._action = None
        self._failure_threshold = None
        self._action_expiration_in_seconds = None
        self._set_http_header = None
        self._challenge_settings = None
        self._are_redirects_challenged = None
        self._criteria = None
        self._is_nat_enabled = None

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this JsChallenge.
        Enables or disables the JavaScript challenge Web Application Firewall feature.


        :return: The is_enabled of this JsChallenge.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this JsChallenge.
        Enables or disables the JavaScript challenge Web Application Firewall feature.


        :param is_enabled: The is_enabled of this JsChallenge.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def action(self):
        """
        Gets the action of this JsChallenge.
        The action to take against requests from detected bots. If unspecified, defaults to `DETECT`.

        Allowed values for this property are: "DETECT", "BLOCK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action of this JsChallenge.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this JsChallenge.
        The action to take against requests from detected bots. If unspecified, defaults to `DETECT`.


        :param action: The action of this JsChallenge.
        :type: str
        """
        allowed_values = ["DETECT", "BLOCK"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            action = 'UNKNOWN_ENUM_VALUE'
        self._action = action

    @property
    def failure_threshold(self):
        """
        Gets the failure_threshold of this JsChallenge.
        The number of failed requests before taking action. If unspecified, defaults to `10`.


        :return: The failure_threshold of this JsChallenge.
        :rtype: int
        """
        return self._failure_threshold

    @failure_threshold.setter
    def failure_threshold(self, failure_threshold):
        """
        Sets the failure_threshold of this JsChallenge.
        The number of failed requests before taking action. If unspecified, defaults to `10`.


        :param failure_threshold: The failure_threshold of this JsChallenge.
        :type: int
        """
        self._failure_threshold = failure_threshold

    @property
    def action_expiration_in_seconds(self):
        """
        Gets the action_expiration_in_seconds of this JsChallenge.
        The number of seconds between challenges from the same IP address. If unspecified, defaults to `60`.


        :return: The action_expiration_in_seconds of this JsChallenge.
        :rtype: int
        """
        return self._action_expiration_in_seconds

    @action_expiration_in_seconds.setter
    def action_expiration_in_seconds(self, action_expiration_in_seconds):
        """
        Sets the action_expiration_in_seconds of this JsChallenge.
        The number of seconds between challenges from the same IP address. If unspecified, defaults to `60`.


        :param action_expiration_in_seconds: The action_expiration_in_seconds of this JsChallenge.
        :type: int
        """
        self._action_expiration_in_seconds = action_expiration_in_seconds

    @property
    def set_http_header(self):
        """
        Gets the set_http_header of this JsChallenge.
        Adds an additional HTTP header to requests that fail the challenge before being passed to the origin. Only applicable when the `action` is set to `DETECT`.


        :return: The set_http_header of this JsChallenge.
        :rtype: oci.waas.models.Header
        """
        return self._set_http_header

    @set_http_header.setter
    def set_http_header(self, set_http_header):
        """
        Sets the set_http_header of this JsChallenge.
        Adds an additional HTTP header to requests that fail the challenge before being passed to the origin. Only applicable when the `action` is set to `DETECT`.


        :param set_http_header: The set_http_header of this JsChallenge.
        :type: oci.waas.models.Header
        """
        self._set_http_header = set_http_header

    @property
    def challenge_settings(self):
        """
        Gets the challenge_settings of this JsChallenge.

        :return: The challenge_settings of this JsChallenge.
        :rtype: oci.waas.models.BlockChallengeSettings
        """
        return self._challenge_settings

    @challenge_settings.setter
    def challenge_settings(self, challenge_settings):
        """
        Sets the challenge_settings of this JsChallenge.

        :param challenge_settings: The challenge_settings of this JsChallenge.
        :type: oci.waas.models.BlockChallengeSettings
        """
        self._challenge_settings = challenge_settings

    @property
    def are_redirects_challenged(self):
        """
        Gets the are_redirects_challenged of this JsChallenge.
        When enabled, redirect responses from the origin will also be challenged. This will change HTTP 301/302 responses from origin to HTTP 200 with an HTML body containing JavaScript page redirection.


        :return: The are_redirects_challenged of this JsChallenge.
        :rtype: bool
        """
        return self._are_redirects_challenged

    @are_redirects_challenged.setter
    def are_redirects_challenged(self, are_redirects_challenged):
        """
        Sets the are_redirects_challenged of this JsChallenge.
        When enabled, redirect responses from the origin will also be challenged. This will change HTTP 301/302 responses from origin to HTTP 200 with an HTML body containing JavaScript page redirection.


        :param are_redirects_challenged: The are_redirects_challenged of this JsChallenge.
        :type: bool
        """
        self._are_redirects_challenged = are_redirects_challenged

    @property
    def criteria(self):
        """
        Gets the criteria of this JsChallenge.
        When defined, the JavaScript Challenge would be applied only for the requests that matched all the listed conditions.


        :return: The criteria of this JsChallenge.
        :rtype: list[oci.waas.models.AccessRuleCriteria]
        """
        return self._criteria

    @criteria.setter
    def criteria(self, criteria):
        """
        Sets the criteria of this JsChallenge.
        When defined, the JavaScript Challenge would be applied only for the requests that matched all the listed conditions.


        :param criteria: The criteria of this JsChallenge.
        :type: list[oci.waas.models.AccessRuleCriteria]
        """
        self._criteria = criteria

    @property
    def is_nat_enabled(self):
        """
        Gets the is_nat_enabled of this JsChallenge.
        When enabled, the user is identified not only by the IP address but also by an unique additional hash, which prevents blocking visitors with shared IP addresses.


        :return: The is_nat_enabled of this JsChallenge.
        :rtype: bool
        """
        return self._is_nat_enabled

    @is_nat_enabled.setter
    def is_nat_enabled(self, is_nat_enabled):
        """
        Sets the is_nat_enabled of this JsChallenge.
        When enabled, the user is identified not only by the IP address but also by an unique additional hash, which prevents blocking visitors with shared IP addresses.


        :param is_nat_enabled: The is_nat_enabled of this JsChallenge.
        :type: bool
        """
        self._is_nat_enabled = is_nat_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeploymentSummary(object):
    """
    Summary of the Deployment.
    """

    #: A constant which can be used with the lifecycle_state property of a DeploymentSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DeploymentSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DeploymentSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DeploymentSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DeploymentSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DeploymentSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DeploymentSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the license_model property of a DeploymentSummary.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a DeploymentSummary.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    #: A constant which can be used with the deployment_type property of a DeploymentSummary.
    #: This constant has a value of "OGG"
    DEPLOYMENT_TYPE_OGG = "OGG"

    def __init__(self, **kwargs):
        """
        Initializes a new DeploymentSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DeploymentSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this DeploymentSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this DeploymentSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DeploymentSummary.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this DeploymentSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DeploymentSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DeploymentSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DeploymentSummary.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DeploymentSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DeploymentSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param subnet_id:
            The value to assign to the subnet_id property of this DeploymentSummary.
        :type subnet_id: str

        :param license_model:
            The value to assign to the license_model property of this DeploymentSummary.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type license_model: str

        :param fqdn:
            The value to assign to the fqdn property of this DeploymentSummary.
        :type fqdn: str

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this DeploymentSummary.
        :type cpu_core_count: int

        :param is_auto_scaling_enabled:
            The value to assign to the is_auto_scaling_enabled property of this DeploymentSummary.
        :type is_auto_scaling_enabled: bool

        :param is_public:
            The value to assign to the is_public property of this DeploymentSummary.
        :type is_public: bool

        :param public_ip_address:
            The value to assign to the public_ip_address property of this DeploymentSummary.
        :type public_ip_address: str

        :param private_ip_address:
            The value to assign to the private_ip_address property of this DeploymentSummary.
        :type private_ip_address: str

        :param deployment_url:
            The value to assign to the deployment_url property of this DeploymentSummary.
        :type deployment_url: str

        :param system_tags:
            The value to assign to the system_tags property of this DeploymentSummary.
        :type system_tags: dict(str, dict(str, object))

        :param is_latest_version:
            The value to assign to the is_latest_version property of this DeploymentSummary.
        :type is_latest_version: bool

        :param deployment_type:
            The value to assign to the deployment_type property of this DeploymentSummary.
            Allowed values for this property are: "OGG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type deployment_type: str

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'subnet_id': 'str',
            'license_model': 'str',
            'fqdn': 'str',
            'cpu_core_count': 'int',
            'is_auto_scaling_enabled': 'bool',
            'is_public': 'bool',
            'public_ip_address': 'str',
            'private_ip_address': 'str',
            'deployment_url': 'str',
            'system_tags': 'dict(str, dict(str, object))',
            'is_latest_version': 'bool',
            'deployment_type': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'subnet_id': 'subnetId',
            'license_model': 'licenseModel',
            'fqdn': 'fqdn',
            'cpu_core_count': 'cpuCoreCount',
            'is_auto_scaling_enabled': 'isAutoScalingEnabled',
            'is_public': 'isPublic',
            'public_ip_address': 'publicIpAddress',
            'private_ip_address': 'privateIpAddress',
            'deployment_url': 'deploymentUrl',
            'system_tags': 'systemTags',
            'is_latest_version': 'isLatestVersion',
            'deployment_type': 'deploymentType'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._subnet_id = None
        self._license_model = None
        self._fqdn = None
        self._cpu_core_count = None
        self._is_auto_scaling_enabled = None
        self._is_public = None
        self._public_ip_address = None
        self._private_ip_address = None
        self._deployment_url = None
        self._system_tags = None
        self._is_latest_version = None
        self._deployment_type = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DeploymentSummary.
        The `OCID`__ of the deployment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this DeploymentSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DeploymentSummary.
        The `OCID`__ of the deployment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this DeploymentSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this DeploymentSummary.
        An object's Display Name.


        :return: The display_name of this DeploymentSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DeploymentSummary.
        An object's Display Name.


        :param display_name: The display_name of this DeploymentSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this DeploymentSummary.
        Metadata about this specific object.


        :return: The description of this DeploymentSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DeploymentSummary.
        Metadata about this specific object.


        :param description: The description of this DeploymentSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DeploymentSummary.
        The `OCID`__ of the compartment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this DeploymentSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DeploymentSummary.
        The `OCID`__ of the compartment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this DeploymentSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_created(self):
        """
        Gets the time_created of this DeploymentSummary.
        The time the resource was created. The format is defined by `RFC3339`__, such as `2016-08-25T21:10:29.600Z`.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this DeploymentSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DeploymentSummary.
        The time the resource was created. The format is defined by `RFC3339`__, such as `2016-08-25T21:10:29.600Z`.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this DeploymentSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this DeploymentSummary.
        The time the resource was last updated. The format is defined by `RFC3339`__, such as `2016-08-25T21:10:29.600Z`.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this DeploymentSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DeploymentSummary.
        The time the resource was last updated. The format is defined by `RFC3339`__, such as `2016-08-25T21:10:29.600Z`.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this DeploymentSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this DeploymentSummary.
        Possible lifecycle states.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DeploymentSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DeploymentSummary.
        Possible lifecycle states.


        :param lifecycle_state: The lifecycle_state of this DeploymentSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this DeploymentSummary.
        Describes the object's current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.


        :return: The lifecycle_details of this DeploymentSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this DeploymentSummary.
        Describes the object's current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.


        :param lifecycle_details: The lifecycle_details of this DeploymentSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DeploymentSummary.
        A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DeploymentSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DeploymentSummary.
        A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DeploymentSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DeploymentSummary.
        Tags defined for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DeploymentSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DeploymentSummary.
        Tags defined for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DeploymentSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this DeploymentSummary.
        The `OCID`__ of the subnet being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this DeploymentSummary.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this DeploymentSummary.
        The `OCID`__ of the subnet being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this DeploymentSummary.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def license_model(self):
        """
        **[Required]** Gets the license_model of this DeploymentSummary.
        The Oracle license model that applies to a Deployment.

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The license_model of this DeploymentSummary.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this DeploymentSummary.
        The Oracle license model that applies to a Deployment.


        :param license_model: The license_model of this DeploymentSummary.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            license_model = 'UNKNOWN_ENUM_VALUE'
        self._license_model = license_model

    @property
    def fqdn(self):
        """
        Gets the fqdn of this DeploymentSummary.
        A three-label Fully Qualified Domain Name (FQDN) for a resource.


        :return: The fqdn of this DeploymentSummary.
        :rtype: str
        """
        return self._fqdn

    @fqdn.setter
    def fqdn(self, fqdn):
        """
        Sets the fqdn of this DeploymentSummary.
        A three-label Fully Qualified Domain Name (FQDN) for a resource.


        :param fqdn: The fqdn of this DeploymentSummary.
        :type: str
        """
        self._fqdn = fqdn

    @property
    def cpu_core_count(self):
        """
        Gets the cpu_core_count of this DeploymentSummary.
        The Minimum number of OCPUs to be made available for this Deployment.


        :return: The cpu_core_count of this DeploymentSummary.
        :rtype: int
        """
        return self._cpu_core_count

    @cpu_core_count.setter
    def cpu_core_count(self, cpu_core_count):
        """
        Sets the cpu_core_count of this DeploymentSummary.
        The Minimum number of OCPUs to be made available for this Deployment.


        :param cpu_core_count: The cpu_core_count of this DeploymentSummary.
        :type: int
        """
        self._cpu_core_count = cpu_core_count

    @property
    def is_auto_scaling_enabled(self):
        """
        Gets the is_auto_scaling_enabled of this DeploymentSummary.
        Indicates if auto scaling is enabled for the Deployment's CPU core count.


        :return: The is_auto_scaling_enabled of this DeploymentSummary.
        :rtype: bool
        """
        return self._is_auto_scaling_enabled

    @is_auto_scaling_enabled.setter
    def is_auto_scaling_enabled(self, is_auto_scaling_enabled):
        """
        Sets the is_auto_scaling_enabled of this DeploymentSummary.
        Indicates if auto scaling is enabled for the Deployment's CPU core count.


        :param is_auto_scaling_enabled: The is_auto_scaling_enabled of this DeploymentSummary.
        :type: bool
        """
        self._is_auto_scaling_enabled = is_auto_scaling_enabled

    @property
    def is_public(self):
        """
        Gets the is_public of this DeploymentSummary.
        True if this object is publicly available.


        :return: The is_public of this DeploymentSummary.
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """
        Sets the is_public of this DeploymentSummary.
        True if this object is publicly available.


        :param is_public: The is_public of this DeploymentSummary.
        :type: bool
        """
        self._is_public = is_public

    @property
    def public_ip_address(self):
        """
        Gets the public_ip_address of this DeploymentSummary.
        The public IP address representing the access point for the Deployment.


        :return: The public_ip_address of this DeploymentSummary.
        :rtype: str
        """
        return self._public_ip_address

    @public_ip_address.setter
    def public_ip_address(self, public_ip_address):
        """
        Sets the public_ip_address of this DeploymentSummary.
        The public IP address representing the access point for the Deployment.


        :param public_ip_address: The public_ip_address of this DeploymentSummary.
        :type: str
        """
        self._public_ip_address = public_ip_address

    @property
    def private_ip_address(self):
        """
        Gets the private_ip_address of this DeploymentSummary.
        The private IP address in the customer's VCN representing the access point for the associated endpoint service in the GoldenGate service VCN.


        :return: The private_ip_address of this DeploymentSummary.
        :rtype: str
        """
        return self._private_ip_address

    @private_ip_address.setter
    def private_ip_address(self, private_ip_address):
        """
        Sets the private_ip_address of this DeploymentSummary.
        The private IP address in the customer's VCN representing the access point for the associated endpoint service in the GoldenGate service VCN.


        :param private_ip_address: The private_ip_address of this DeploymentSummary.
        :type: str
        """
        self._private_ip_address = private_ip_address

    @property
    def deployment_url(self):
        """
        Gets the deployment_url of this DeploymentSummary.
        The URL of a resource.


        :return: The deployment_url of this DeploymentSummary.
        :rtype: str
        """
        return self._deployment_url

    @deployment_url.setter
    def deployment_url(self, deployment_url):
        """
        Sets the deployment_url of this DeploymentSummary.
        The URL of a resource.


        :param deployment_url: The deployment_url of this DeploymentSummary.
        :type: str
        """
        self._deployment_url = deployment_url

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DeploymentSummary.
        The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces.  For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this DeploymentSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DeploymentSummary.
        The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces.  For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this DeploymentSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    @property
    def is_latest_version(self):
        """
        Gets the is_latest_version of this DeploymentSummary.
        Indicates if the resource is the the latest available version.


        :return: The is_latest_version of this DeploymentSummary.
        :rtype: bool
        """
        return self._is_latest_version

    @is_latest_version.setter
    def is_latest_version(self, is_latest_version):
        """
        Sets the is_latest_version of this DeploymentSummary.
        Indicates if the resource is the the latest available version.


        :param is_latest_version: The is_latest_version of this DeploymentSummary.
        :type: bool
        """
        self._is_latest_version = is_latest_version

    @property
    def deployment_type(self):
        """
        Gets the deployment_type of this DeploymentSummary.
        The deployment type.

        Allowed values for this property are: "OGG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The deployment_type of this DeploymentSummary.
        :rtype: str
        """
        return self._deployment_type

    @deployment_type.setter
    def deployment_type(self, deployment_type):
        """
        Sets the deployment_type of this DeploymentSummary.
        The deployment type.


        :param deployment_type: The deployment_type of this DeploymentSummary.
        :type: str
        """
        allowed_values = ["OGG"]
        if not value_allowed_none_or_none_sentinel(deployment_type, allowed_values):
            deployment_type = 'UNKNOWN_ENUM_VALUE'
        self._deployment_type = deployment_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationBlockVolumeDetails(object):
    """
    Create new block volumes or attach to an existing volume. Specify either createDetails or volumeId.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationBlockVolumeDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param attach_details:
            The value to assign to the attach_details property of this InstanceConfigurationBlockVolumeDetails.
        :type attach_details: oci.core.models.InstanceConfigurationAttachVolumeDetails

        :param create_details:
            The value to assign to the create_details property of this InstanceConfigurationBlockVolumeDetails.
        :type create_details: oci.core.models.InstanceConfigurationCreateVolumeDetails

        :param volume_id:
            The value to assign to the volume_id property of this InstanceConfigurationBlockVolumeDetails.
        :type volume_id: str

        """
        self.swagger_types = {
            'attach_details': 'InstanceConfigurationAttachVolumeDetails',
            'create_details': 'InstanceConfigurationCreateVolumeDetails',
            'volume_id': 'str'
        }

        self.attribute_map = {
            'attach_details': 'attachDetails',
            'create_details': 'createDetails',
            'volume_id': 'volumeId'
        }

        self._attach_details = None
        self._create_details = None
        self._volume_id = None

    @property
    def attach_details(self):
        """
        Gets the attach_details of this InstanceConfigurationBlockVolumeDetails.

        :return: The attach_details of this InstanceConfigurationBlockVolumeDetails.
        :rtype: oci.core.models.InstanceConfigurationAttachVolumeDetails
        """
        return self._attach_details

    @attach_details.setter
    def attach_details(self, attach_details):
        """
        Sets the attach_details of this InstanceConfigurationBlockVolumeDetails.

        :param attach_details: The attach_details of this InstanceConfigurationBlockVolumeDetails.
        :type: oci.core.models.InstanceConfigurationAttachVolumeDetails
        """
        self._attach_details = attach_details

    @property
    def create_details(self):
        """
        Gets the create_details of this InstanceConfigurationBlockVolumeDetails.

        :return: The create_details of this InstanceConfigurationBlockVolumeDetails.
        :rtype: oci.core.models.InstanceConfigurationCreateVolumeDetails
        """
        return self._create_details

    @create_details.setter
    def create_details(self, create_details):
        """
        Sets the create_details of this InstanceConfigurationBlockVolumeDetails.

        :param create_details: The create_details of this InstanceConfigurationBlockVolumeDetails.
        :type: oci.core.models.InstanceConfigurationCreateVolumeDetails
        """
        self._create_details = create_details

    @property
    def volume_id(self):
        """
        Gets the volume_id of this InstanceConfigurationBlockVolumeDetails.
        The OCID of the volume.


        :return: The volume_id of this InstanceConfigurationBlockVolumeDetails.
        :rtype: str
        """
        return self._volume_id

    @volume_id.setter
    def volume_id(self, volume_id):
        """
        Sets the volume_id of this InstanceConfigurationBlockVolumeDetails.
        The OCID of the volume.


        :param volume_id: The volume_id of this InstanceConfigurationBlockVolumeDetails.
        :type: str
        """
        self._volume_id = volume_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecurityAssessmentComparison(object):
    """
    Provides a list of the differences in a comparison of the security assessment with the baseline value.
    """

    #: A constant which can be used with the lifecycle_state property of a SecurityAssessmentComparison.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SecurityAssessmentComparison.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a SecurityAssessmentComparison.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new SecurityAssessmentComparison object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SecurityAssessmentComparison.
        :type id: str

        :param baseline_id:
            The value to assign to the baseline_id property of this SecurityAssessmentComparison.
        :type baseline_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SecurityAssessmentComparison.
            Allowed values for this property are: "CREATING", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this SecurityAssessmentComparison.
        :type time_created: datetime

        :param targets:
            The value to assign to the targets property of this SecurityAssessmentComparison.
        :type targets: list[oci.data_safe.models.SecurityAssessmentComparisonPerTarget]

        """
        self.swagger_types = {
            'id': 'str',
            'baseline_id': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'targets': 'list[SecurityAssessmentComparisonPerTarget]'
        }

        self.attribute_map = {
            'id': 'id',
            'baseline_id': 'baselineId',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'targets': 'targets'
        }

        self._id = None
        self._baseline_id = None
        self._lifecycle_state = None
        self._time_created = None
        self._targets = None

    @property
    def id(self):
        """
        Gets the id of this SecurityAssessmentComparison.
        The OCID of the security assessment that is being compared with a baseline security assessment.


        :return: The id of this SecurityAssessmentComparison.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SecurityAssessmentComparison.
        The OCID of the security assessment that is being compared with a baseline security assessment.


        :param id: The id of this SecurityAssessmentComparison.
        :type: str
        """
        self._id = id

    @property
    def baseline_id(self):
        """
        Gets the baseline_id of this SecurityAssessmentComparison.
        The OCID of the security assessment that is set as a baseline.


        :return: The baseline_id of this SecurityAssessmentComparison.
        :rtype: str
        """
        return self._baseline_id

    @baseline_id.setter
    def baseline_id(self, baseline_id):
        """
        Sets the baseline_id of this SecurityAssessmentComparison.
        The OCID of the security assessment that is set as a baseline.


        :param baseline_id: The baseline_id of this SecurityAssessmentComparison.
        :type: str
        """
        self._baseline_id = baseline_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this SecurityAssessmentComparison.
        The current state of the security assessment comparison.

        Allowed values for this property are: "CREATING", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SecurityAssessmentComparison.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SecurityAssessmentComparison.
        The current state of the security assessment comparison.


        :param lifecycle_state: The lifecycle_state of this SecurityAssessmentComparison.
        :type: str
        """
        allowed_values = ["CREATING", "SUCCEEDED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this SecurityAssessmentComparison.
        The date and time when the security assessment comparison was created. Conforms to the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this SecurityAssessmentComparison.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SecurityAssessmentComparison.
        The date and time when the security assessment comparison was created. Conforms to the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this SecurityAssessmentComparison.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def targets(self):
        """
        Gets the targets of this SecurityAssessmentComparison.
        A target-based comparison between two security assessments.


        :return: The targets of this SecurityAssessmentComparison.
        :rtype: list[oci.data_safe.models.SecurityAssessmentComparisonPerTarget]
        """
        return self._targets

    @targets.setter
    def targets(self, targets):
        """
        Sets the targets of this SecurityAssessmentComparison.
        A target-based comparison between two security assessments.


        :param targets: The targets of this SecurityAssessmentComparison.
        :type: list[oci.data_safe.models.SecurityAssessmentComparisonPerTarget]
        """
        self._targets = targets

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
